var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { fetchDelete, fetchGet, fetchGetBlob, fetchPost, fetchPut } from "../../../utils/fetch";
export class TorrentResource {
    constructor(client) {
        this.client = client;
    }
    headers() {
        return this.client.authToken ? { "Authorization": `Bearer ${this.client.authToken}` } : undefined;
    }
    getTorrentInfo(infoHash) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchGet(`${this.client.apiBaseUrl}/torrent/${infoHash}`, this.headers())
                .then((res) => {
                return Promise.resolve(res.data);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    getTorrents(params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchGet(`${this.client.apiBaseUrl}/torrents?page_size=${params.pageSize}&page=${params.page - 1}&sort=${params.sorting}${params.categories ? "&categories=" + params.categories.join(",") : ""}${params.tags ? "&tags=" + params.tags.join(",") : ""}${params.searchQuery ? "&search=" + params.searchQuery : ""}`, this.headers())
                .then((res) => {
                return Promise.resolve(res.data);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    deleteTorrent(infoHash) {
        return __awaiter(this, void 0, void 0, function* () {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            return yield fetchDelete(`${this.client.apiBaseUrl}/torrent/${infoHash}`, {}, this.headers())
                .then((res) => {
                return Promise.resolve(res.data);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    updateTorrent(infoHash, params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchPut(`${this.client.apiBaseUrl}/torrent/${infoHash}`, params, this.headers())
                .then((res) => {
                return Promise.resolve(res.data);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    uploadTorrent(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const formData = new FormData();
            formData.append("title", params.title);
            formData.append("description", params.description);
            formData.append("category", params.category);
            formData.append("tags", JSON.stringify(params.tags));
            formData.append("torrent", params.file);
            return yield fetchPost(`${this.client.apiBaseUrl}/torrent/upload`, formData, this.headers())
                .then((res) => {
                return Promise.resolve(res.data);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    downloadTorrent(infoHash) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchGetBlob(`${this.client.apiBaseUrl}/torrent/download/${infoHash}`, this.headers())
                .then((blob) => {
                return Promise.resolve(blob);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    proxiedImage(url) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchGetBlob(`${this.client.apiBaseUrl}/proxy/image/${encodeURIComponent(url)}`, this.headers())
                .then((blob) => {
                return Promise.resolve(blob);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
}
//# sourceMappingURL=torrent.js.map