var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { fetchGet, fetchPost } from "../../../utils/fetch";
export class UserResource {
    constructor(client) {
        this.client = client;
    }
    loginUser(params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchPost(`${this.client.apiBaseUrl}/user/login`, JSON.stringify(params), { "Content-Type": "application/json" })
                .then((res) => {
                // Update auth token.
                this.client.setToken(res.data.token);
                return Promise.resolve(res.data);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    registerUser(params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchPost(`${this.client.apiBaseUrl}/user/register`, JSON.stringify(params), { "Content-Type": "application/json" })
                .then(() => {
                return Promise.resolve(true);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    renewToken() {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            return yield fetchPost(`${this.client.apiBaseUrl}/user/token/renew`, JSON.stringify({ token: (_a = this.client.authToken) !== null && _a !== void 0 ? _a : "" }), { "Content-Type": "application/json" })
                .then((res) => {
                // Update auth token.
                this.client.setToken(res.data.token);
                return Promise.resolve(res.data);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    changePassword(params, username) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchPost(`${this.client.apiBaseUrl}/user/${username}/change-password`, JSON.stringify(params), {
                "Authorization": `Bearer ${this.client.authToken}`,
                "Content-Type": "application/json"
            })
                .then(() => {
                return Promise.resolve(true);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
    getUserProfiles(params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield fetchGet(`${this.client.apiBaseUrl}/users?page_size=${params.pageSize}&page=${params.page - 1}&sort=${params.sorting}${params.filters ? "&filters=" + params.filters.join(",") : ""}${params.searchQuery ? "&search=" + params.searchQuery : ""}`, {
                "Authorization": `Bearer ${this.client.authToken}`,
                "Content-Type": "application/json"
            })
                .then((res) => {
                return Promise.resolve(res.data);
            })
                .catch((err) => {
                var _a, _b, _c;
                return Promise.reject((_c = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) !== null && _c !== void 0 ? _c : err);
            });
        });
    }
}
//# sourceMappingURL=user.js.map