import { CategoryResource } from "./resources/category";
import { SettingsResource } from "./resources/settings";
import { TorrentResource } from "./resources/torrent";
import { UserResource } from "./resources/user";
import { TagResource } from "./resources/tag";
const LOCAL_STORAGE_TOKEN_KEY = "torrust_token";
export class Rest {
    constructor(apiBaseUrl) {
        this.apiBaseUrl = apiBaseUrl;
        this.getToken();
        this.category = new CategoryResource(this);
        this.settings = new SettingsResource(this);
        this.torrent = new TorrentResource(this);
        this.user = new UserResource(this);
        this.tag = new TagResource(this);
    }
    getToken() {
        // Should only work in a browser, not in Node.
        if (typeof window === "undefined")
            return;
        // Read user json from local storage.
        const authToken = window.localStorage.getItem(LOCAL_STORAGE_TOKEN_KEY);
        if (authToken) {
            this.setToken(authToken);
        }
    }
    setToken(authToken) {
        // Should only work in a browser, not in Node.
        if (typeof window === "undefined")
            return;
        this.authToken = authToken;
        window.localStorage.setItem(LOCAL_STORAGE_TOKEN_KEY, authToken);
    }
    deleteToken() {
        // Should only work in a browser, not in Node.
        if (typeof window === "undefined")
            return;
        this.authToken = undefined;
        window.localStorage.removeItem(LOCAL_STORAGE_TOKEN_KEY);
    }
}
//# sourceMappingURL=rest.js.map